# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation

Self = typing.TypeVar('Self')

@typing.final
class VibrationDevice_Static(winrt._winrt.IInspectable_Static):
    # Windows.Phone.Devices.Notification.VibrationDevice Windows.Phone.Devices.Notification.VibrationDevice::GetDefault()
    def get_default(cls) -> VibrationDevice: ...

@typing.final
class VibrationDevice(winrt.system.Object, metaclass=VibrationDevice_Static):
    # System.Void Windows.Phone.Devices.Notification.VibrationDevice::Cancel()
    def cancel(self) -> None: ...
    # System.Void Windows.Phone.Devices.Notification.VibrationDevice::Vibrate(Windows.Foundation.TimeSpan)
    def vibrate(self, duration: datetime.timedelta, /) -> None: ...

